@@ -6,7 +6,7 @@ use DBIx::ThinSQL qw//;
 use DBIx::ThinSQL::SQLite ':all';
 use Log::Any '$log';
 
-our $VERSION = '0.1.0_17';
+our $VERSION = '0.1.0_18';
 our @ISA     = ('Bif::DB');
 
 create_methods(qw/nextval currval/);
@@ -113,11 +113,11 @@ sub update_repo {
     $dbw->xdo(
         insert_into =>
           [ 'hub_updates', qw/hub_id update_id related_update_uuid/ ],
-        select    => [ qv( $hub->{id} ), qv($uid), 'hu.uuid', ],
+        select    => [ qv( $hub->{id} ), qv($uid), 'u.uuid', ],
         from      => '(select 1)',
-        left_join => 'topics hu',
+        left_join => 'updates u',
         on        => {
-            'hu.id' => $ref->{related_update_id},
+            'u.id' => $ref->{related_update_id},
         },
     );
 
@@ -140,7 +140,7 @@ Bif::DBW - read-write helper methods for a bif database
 
 =head1 VERSION
 
-0.1.0_17 (2014-05-02)
+0.1.0_18 (2014-05-04)
 
 =head1 SYNOPSIS
 
@@ -197,7 +197,10 @@ the previous (possibly 0) and newly deployed versions.
 =item update_repo($hashref)
 
 Create an update of the local repo from a hashref containing a user
-name, a user email, and a message.
+name, a user email, and a message. C<$hashref> can optionally contain
+an update_id which will be converted into a uuid, used for uniqueness
+in the event that multiple calls to update_repo with the same values
+occur in the same second.
 
 =back
 
