@@ -1,4 +1,5 @@
 CREATE TABLE func_import_task_status(
+    update_uuid VARCHAR(40) NOT NULL,
     project_uuid VARCHAR(40) NOT NULL,
     status VARCHAR(40) NOT NULL,
     rank INTEGER NOT NULL,
@@ -14,7 +15,7 @@ FOR EACH ROW
 BEGIN
 
     SELECT debug(
-        'TRIGGER bi_func_import_task_status_1',
+        NEW.update_uuid,
         NEW.project_uuid,
         NEW.status,
         NEW.rank,
@@ -23,18 +24,24 @@ BEGIN
 
     INSERT INTO
         func_new_task_status(
+            update_id,
             project_id,
             status,
             rank,
             def
         )
     SELECT
+        u.id,
         projects.id,
         NEW.status,
         NEW.rank,
         NEW.def
     FROM
         topics AS projects
+    INNER JOIN
+        updates u
+    ON
+        u.uuid = NEW.update_uuid
     WHERE
         projects.uuid = NEW.project_uuid
     ;
